Remediation actions may be vastly different depending on the framework
being used, and how the application has been coded. However, the
origin header should never be used to validate a client's access as it
is trivial to change.